//
//  preferences.h
//  CalcIsoStruct
//
//  Created by Christian Gerber on 1/30/13.
//  Copyright (c) 2013 Eawag. All rights reserved.
//

#ifndef CalcIsoStruct_preferences_h
#define CalcIsoStruct_preferences_h

// allowed size of Element name, Isotope name
#define MAX_NAME_SIZE 10

// allowed size of all the isotopes over all occuring elements
#define MAX_ISO_SIZE 50

// allowed size of isotopes for a single element
#define MAX_ISO_ELEM 20

// allowed size of different elements within the sum formula
#define MAX_ELEMENTS 20

// allowed size of different compounds
#define MAX_COMPOUNDS 400000

// allowed size of different compounds
#define MAX_COMPOUNDS_2 200000

// allowed size of different compounds
#define MAX_COMPOUNDS_A2 400000

// allowed size of different compounds within A list
#define MAX_COMPOUNDS_A 20000

// allowed amount of maximum peaks
#define MAX_PEAKS 1000000

#endif
